@@ -16,14 +16,31 @@
 # limitations under the License.
 # ------------------------------------------------------------------------
 
+from abc import abstractmethod
+
 import numpy as np
 import scipy.ndimage.morphology
 import skimage.morphology
 
 from . import morphological_filters_functional as F
+from .image_filters import Filter
+
+try:
+    from typing import Protocol, runtime_checkable
+except ImportError:
+    from typing_extensions import Protocol, runtime_checkable
 
 
-class RemoveSmallObjects(object):
+@runtime_checkable
+class MorphologicalFilter(Filter, Protocol):
+    """Morphological filter base class"""
+
+    @abstractmethod
+    def __call__(self, np_mask: np.ndarray) -> np.ndarray:
+        raise NotImplementedError
+
+
+class RemoveSmallObjects(MorphologicalFilter):
     """Remove objects smaller than the specified size.
 
     If avoid_overmask is True, this function can recursively call itself with
@@ -57,16 +74,13 @@ class RemoveSmallObjects(object):
         self.avoid_overmask = avoid_overmask
         self.overmask_thresh = overmask_thresh
 
-    def __call__(self, np_img) -> np.ndarray:
+    def __call__(self, np_mask: np.ndarray) -> np.ndarray:
         return F.remove_small_objects(
-            np_img, self.min_size, self.avoid_overmask, self.overmask_thresh
+            np_mask, self.min_size, self.avoid_overmask, self.overmask_thresh
         )
 
-    def __repr__(self):
-        return self.__class__.__name__ + "()"
 
-
-class RemoveSmallHoles(object):
+class RemoveSmallHoles(MorphologicalFilter):
     """Remove holes smaller than a specified size.
 
     Parameters
@@ -85,14 +99,11 @@ class RemoveSmallHoles(object):
     def __init__(self, area_threshold: int = 3000):
         self.area_threshold = area_threshold
 
-    def __call__(self, np_mask) -> np.ndarray:
+    def __call__(self, np_mask: np.ndarray) -> np.ndarray:
         return skimage.morphology.remove_small_holes(np_mask, self.area_threshold)
 
-    def __repr__(self):
-        return self.__class__.__name__ + "()"
 
-
-class BinaryErosion(object):
+class BinaryErosion(MorphologicalFilter):
     """Erode a binary mask.
 
     Parameters
@@ -122,11 +133,8 @@ class BinaryErosion(object):
             np_mask, skimage.morphology.disk(self.disk_size), self.iterations
         )
 
-    def __repr__(self):
-        return self.__class__.__name__ + "()"
 
-
-class BinaryDilation(object):
+class BinaryDilation(MorphologicalFilter):
     """Dilate a binary mask.
 
     Parameters
@@ -155,11 +163,8 @@ class BinaryDilation(object):
             np_mask, skimage.morphology.disk(self.disk_size), self.iterations
         )
 
-    def __repr__(self):
-        return self.__class__.__name__ + "()"
 
-
-class BinaryFillHoles(object):
+class BinaryFillHoles(MorphologicalFilter):
     """Fill the holes in binary objects.
 
     Parameters
@@ -183,7 +188,7 @@ class BinaryFillHoles(object):
         return scipy.ndimage.morphology.binary_fill_holes(np_img, self.structure)
 
 
-class BinaryOpening(object):
+class BinaryOpening(MorphologicalFilter):
     """Open a binary mask.
 
     Opening is an erosion followed by a dilation. Opening can be used to remove
@@ -208,18 +213,15 @@ class BinaryOpening(object):
         self.disk_size = disk_size
         self.iterations = iterations
 
-    def __call__(self, np_mask) -> np.ndarray:
+    def __call__(self, np_mask: np.ndarray) -> np.ndarray:
         if not np.array_equal(np_mask, np_mask.astype(bool)):
             raise ValueError("Mask must be binary")
         return scipy.ndimage.morphology.binary_opening(
             np_mask, skimage.morphology.disk(self.disk_size), self.iterations
         )
 
-    def __repr__(self):
-        return self.__class__.__name__ + "()"
 
-
-class BinaryClosing(object):
+class BinaryClosing(MorphologicalFilter):
     """Close a binary mask.
 
     Closing is a dilation followed by an erosion. Closing can be used to remove
@@ -244,18 +246,46 @@ class BinaryClosing(object):
         self.disk_size = disk_size
         self.iterations = iterations
 
-    def __call__(self, np_mask) -> np.ndarray:
+    def __call__(self, np_mask: np.ndarray) -> np.ndarray:
         if not np.array_equal(np_mask, np_mask.astype(bool)):
             raise ValueError("Mask must be binary")
         return scipy.ndimage.morphology.binary_closing(
             np_mask, skimage.morphology.disk(self.disk_size), self.iterations
         )
 
-    def __repr__(self):
-        return self.__class__.__name__ + "()"
+
+class WatershedSegmentation(MorphologicalFilter):
+    """Segment and label an binary mask with Watershed segmentation [1]_
+
+    The watershed algorithm treats pixels values as a local topography (elevation).
+
+    Parameters
+    ----------
+    np_mask : np.ndarray
+        Input mask
+    region_shape : int, optional
+        The local region within which to search for image peaks is defined as a squared
+        area region_shape x region_shape. Default is 6.
+
+    Returns
+    -------
+    np.ndarray
+        Labelled segmentation mask
+
+    References
+    --------
+    .. [1] Watershed segmentation.
+       https://scikit-image.org/docs/dev/auto_examples/segmentation/plot_watershed.html
+    """
+
+    def __init__(self, region_shape: int = 6) -> None:
+        self.region_shape = region_shape
+
+    def __call__(self, np_mask: np.ndarray) -> np.ndarray:
+        return F.watershed_segmentation(np_mask, self.region_shape)
 
 
-class WhiteTopHat(object):
+class WhiteTopHat(MorphologicalFilter):
     """Return white top hat of an image.
 
     The white top hat of an image is defined as the image minus its morphological
