@@ -52,14 +52,16 @@ class Slide:
 
     Arguments
     ---------
-    path : str
+    path : Union[str, pathlib.Path]
         Path where the WSI is saved.
-    processed_path : str
+    processed_path : Union[str, pathlib.Path]
         Path where thumbnails and scaled images will be saved to.
     """
 
-    def __init__(self, path: str, processed_path: str) -> None:
-        self._path = path
+    def __init__(
+        self, path: Union[str, pathlib.Path], processed_path: Union[str, pathlib.Path]
+    ) -> None:
+        self._path = str(path) if isinstance(path, pathlib.Path) else path
         self._processed_path = processed_path
 
     def __repr__(self):
