@@ -103,8 +103,13 @@ def test_rgb_to_hed_filter_with_rgba_image():
     expected_value = load_expectation(
         "pil-images-rgba/diagnostic-slide-thumb-rgba-to-hed", type_="png"
     )
+    expected_warning_regex = (
+        r"Input image must be RGB. NOTE: the image will be converted to RGB before"
+        r" HED conversion."
+    )
 
-    hed_img = imf.rgb_to_hed(img)
+    with pytest.warns(UserWarning, match=expected_warning_regex):
+        hed_img = imf.rgb_to_hed(img)
 
     np.testing.assert_array_almost_equal(np.array(hed_img), np.array(expected_value))
     assert np.unique(np.array(ImageChops.difference(hed_img, expected_value)))[0] == 0
@@ -137,8 +142,13 @@ def test_hematoxylin_channel_filter_with_rgba_image():
     expected_value = load_expectation(
         "pil-images-rgba/tcga-lung-hematoxylin-channel", type_="png"
     )
+    expected_warning_regex = (
+        r"Input image must be RGB. NOTE: the image will be converted to RGB before"
+        r" HED conversion."
+    )
 
-    hematoxylin_img = imf.hematoxylin_channel(img)
+    with pytest.warns(UserWarning, match=expected_warning_regex):
+        hematoxylin_img = imf.hematoxylin_channel(img)
 
     np.testing.assert_array_almost_equal(
         np.array(hematoxylin_img), np.array(expected_value)
@@ -176,8 +186,13 @@ def test_eosin_channel_filter_with_rgba_image():
     expected_value = load_expectation(
         "pil-images-rgba/tcga-lung-eosin-channel", type_="png"
     )
+    expected_warning_regex = (
+        r"Input image must be RGB. NOTE: the image will be converted to RGB before"
+        r" HED conversion."
+    )
 
-    eosin_img = imf.eosin_channel(img)
+    with pytest.warns(UserWarning, match=expected_warning_regex):
+        eosin_img = imf.eosin_channel(img)
 
     np.testing.assert_array_almost_equal(np.array(eosin_img), np.array(expected_value))
     assert np.unique(np.array(ImageChops.difference(eosin_img, expected_value)))[0] == 0
@@ -305,7 +320,7 @@ def test_stretch_contrast_filter_on_gs_image():
     (
         (300, 40),
         (300, 600),
-        (40, 500,),
+        (40, 500),
         (-10, 340),
         (-200, 300),
         (-40, -60),
@@ -449,7 +464,7 @@ def test_adaptive_equalization_filter_on_gs_image():
 
 
 @pytest.mark.parametrize(
-    "nbins, clip_limit", ((-10, 340), (-40, -60), (None, 50), (None, None),),
+    "nbins, clip_limit", ((-10, 340), (-40, -60), (None, 50), (None, None))
 )
 def test_adaptive_equalization_raises_exception_on_params(nbins, clip_limit):
     rgba_img = RGBA.DIAGNOSTIC_SLIDE_THUMB
@@ -488,7 +503,6 @@ def test_local_equalization_filter_on_gs_image():
     ),
 )
 def test_local_equalization_raises_exception_on_rgb_images(pil_rgb_image):
-
     with pytest.raises(Exception) as err:
         imf.local_equalization(pil_rgb_image, 80)
 
@@ -696,9 +710,7 @@ def test_hysteresis_threshold_filter_on_gs_image():
     )
 
 
-@pytest.mark.parametrize(
-    "low, high", ((None, 50), (-250, None), (None, None),),
-)
+@pytest.mark.parametrize("low, high", ((None, 50), (-250, None), (None, None)))
 def test_hysteresis_threshold_raises_exception_on_thresholds(low, high):
     rgba_img = RGBA.DIAGNOSTIC_SLIDE_THUMB
 
@@ -779,7 +791,6 @@ def test_local_otsu_threshold_filter_on_gs_image(pil_image, expected_image, disk
 def test_local_otsu_threshold_raises_right_exceptions(
     pil_image, disk_size, expected_exception, expected_message
 ):
-
     with pytest.raises(expected_exception) as err:
         imf.local_otsu_threshold(pil_image, disk_size)
 
@@ -801,9 +812,7 @@ def test_hysteresis_threshold_mask_filter_on_rgba_image():
     np.testing.assert_array_equal(hysteresis_threshold_mask, expected_value)
 
 
-@pytest.mark.parametrize(
-    "low, high", ((None, 50), (-250, None), (None, None),),
-)
+@pytest.mark.parametrize("low, high", ((None, 50), (-250, None), (None, None)))
 def test_hysteresis_threshold_mask_raises_exception_on_thresholds(low, high):
     rgb_img = RGB.DIAGNOSTIC_SLIDE_THUMB_RGB
 
@@ -876,8 +885,13 @@ def test_otsu_threshold_filter_on_rgba_image():
     expected_value = load_expectation(
         "mask-arrays/diagnostic-slide-thumb-otsu-threshold-mask", type_="npy"
     )
+    expected_warning_regex = (
+        r"otsu_threshold is expected to work correctly only for grayscale images.NOTE: "
+        r"the image will be converted to grayscale before applying Otsuthreshold"
+    )
 
-    otsu_threshold_mask = imf.otsu_threshold(rgba_img, operator.gt)
+    with pytest.warns(UserWarning, match=expected_warning_regex):
+        otsu_threshold_mask = imf.otsu_threshold(rgba_img, operator.gt)
 
     np.testing.assert_array_equal(otsu_threshold_mask, expected_value)
 
@@ -901,8 +915,13 @@ def test_otsu_threshold_filter_on_rgba_image():
 )
 def test_otsu_threshold_filter_on_rgb_image(pil_image, expected_array):
     expected_value = load_expectation(expected_array, type_="npy")
+    expected_warning_regex = (
+        r"otsu_threshold is expected to work correctly only for grayscale images.NOTE: "
+        r"the image will be converted to grayscale before applying Otsuthreshold"
+    )
 
-    otsu_threshold_mask = imf.otsu_threshold(pil_image, operator.gt)
+    with pytest.warns(UserWarning, match=expected_warning_regex):
+        otsu_threshold_mask = imf.otsu_threshold(pil_image, operator.gt)
 
     np.testing.assert_array_equal(otsu_threshold_mask, expected_value)
 
@@ -939,7 +958,6 @@ def test_filter_entropy_filter_on_gs_image():
     ),
 )
 def test_filter_entropy_raises_exception_on_rgb_image(pil_image):
-
     with pytest.raises(Exception) as err:
         imf.filter_entropy(pil_image)
 
@@ -968,7 +986,6 @@ def test_canny_edges_filter_on_gs_image():
     ),
 )
 def test_canny_edges_raises_exception_on_rgb_image(pil_image):
-
     with pytest.raises(Exception) as err:
         imf.canny_edges(pil_image)
 
@@ -1150,7 +1167,6 @@ def test_red_filter_on_rgb_image(
 def test_red_filter_raises_right_exceptions(
     pil_img, red_thresh, green_thresh, blue_thresh, expected_exception, expected_message
 ):
-
     with pytest.raises(expected_exception) as err:
         imf.red_filter(pil_img, red_thresh, green_thresh, blue_thresh)
 
@@ -1203,22 +1219,67 @@ def test_red_pen_filter_on_rgb_image(pil_img, expected_value):
 
 
 @pytest.mark.parametrize(
-    "red_thresh, green_thresh, blue_thresh, expected_value",
+    "red_thresh, green_thresh, blue_thresh, expectation",
     (
         (20, 190, 50, "mask-arrays/diagnostic-slide-thumb-rgba1-green-filter-mask"),
         (0, 40, 30, "mask-arrays/diagnostic-slide-thumb-rgba2-green-filter-mask"),
         (0, 180, 90, "mask-arrays/diagnostic-slide-thumb-rgba3-green-filter-mask"),
     ),
 )
-def test_green_filter_on_rgba_image(
-    red_thresh, green_thresh, blue_thresh, expected_value
+def test_green_filter_on_rgba_image(red_thresh, green_thresh, blue_thresh, expectation):
+    rgba_img = RGBA.DIAGNOSTIC_SLIDE_THUMB
+
+    green_filter_mask = imf.green_filter(
+        rgba_img, red_thresh, green_thresh, blue_thresh
+    )
+
+    np.testing.assert_array_equal(
+        green_filter_mask, load_expectation(expectation, type_="npy")
+    )
+
+
+@pytest.mark.parametrize(
+    "green_thresh, avoid_overmask, overmask_thresh, expectation",
+    (
+        (
+            200,
+            True,
+            50,
+            "mask-arrays/diagnostic-slide-thumb-rgba1-green-ch-filter-mask",
+        ),
+        (0, True, 50, "mask-arrays/diagnostic-slide-thumb-rgba2-green-ch-filter-mask"),
+        (
+            200,
+            False,
+            50,
+            "mask-arrays/diagnostic-slide-thumb-rgba3-green-ch-filter-mask",
+        ),
+        (0, False, 50, "mask-arrays/diagnostic-slide-thumb-rgba4-green-ch-filter-mask"),
+    ),
+)
+def test_green_channel_filter_on_rgba_image(
+    green_thresh, avoid_overmask, overmask_thresh, expectation
 ):
     rgba_img = RGBA.DIAGNOSTIC_SLIDE_THUMB
-    expected_value = load_expectation(expected_value, type_="npy")
 
-    red_filter_mask = imf.green_filter(rgba_img, red_thresh, green_thresh, blue_thresh)
+    green_ch_filter_mask = imf.green_channel_filter(
+        rgba_img, green_thresh, avoid_overmask, overmask_thresh
+    )
 
-    np.testing.assert_array_equal(red_filter_mask, expected_value)
+    np.testing.assert_array_equal(
+        green_ch_filter_mask, load_expectation(expectation, type_="npy")
+    )
+    assert rgba_img.size == green_ch_filter_mask.T.shape
+
+
+@pytest.mark.parametrize("green_threshold", (256, -1))
+def test_green_channel_filter_with_wrong_threshold(green_threshold):
+    rgba_img = RGBA.DIAGNOSTIC_SLIDE_THUMB
+    with pytest.raises(ValueError) as err:
+        imf.green_channel_filter(rgba_img, green_threshold)
+
+    assert isinstance(err.value, ValueError)
+    assert str(err.value) == "threshold must be in range [0, 255]"
 
 
 @pytest.mark.parametrize(
@@ -1324,7 +1385,6 @@ def test_green_filter_on_rgb_image(
 def test_green_filter_raises_right_exceptions(
     pil_img, red_thresh, green_thresh, blue_thresh, expected_exception, expected_message
 ):
-
     with pytest.raises(expected_exception) as err:
         imf.green_filter(pil_img, red_thresh, green_thresh, blue_thresh)
 
@@ -1490,7 +1550,6 @@ def test_blue_filter_on_rgb_image(
 def test_blue_filter_raises_right_exceptions(
     pil_img, red_thresh, green_thresh, blue_thresh, expected_exception, expected_message
 ):
-
     with pytest.raises(expected_exception) as err:
         imf.blue_filter(pil_img, red_thresh, green_thresh, blue_thresh)
 
@@ -1582,3 +1641,40 @@ def test_yen_threshold_filter_on_gs_image():
     yen_threshold_mask = imf.yen_threshold(gs_img)
 
     np.testing.assert_array_equal(yen_threshold_mask, expected_value)
+
+
+@pytest.mark.parametrize(
+    "pil_image, expected_image",
+    (
+        (
+            RGB.DIAGNOSTIC_SLIDE_THUMB_RGB,
+            "pil-images-rgb/diagnostic-slide-thumb-rgb-to-lab",
+        ),
+        (
+            RGB.DIAGNOSTIC_SLIDE_THUMB_HSV,
+            "pil-images-rgb/diagnostic-slide-thumb-hsv-rgb-to-lab",
+        ),
+        (
+            RGB.DIAGNOSTIC_SLIDE_THUMB_YCBCR,
+            "pil-images-rgb/diagnostic-slide-thumb-ycbcr-rgb-to-lab",
+        ),
+    ),
+)
+def test_rgb_to_lab_filter_with_rgb_image(pil_image, expected_image):
+    expected_value = load_expectation(expected_image, type_="png")
+
+    lab_img = imf.rgb_to_lab(pil_image)
+
+    np.testing.assert_array_almost_equal(np.array(lab_img), np.array(expected_value))
+    assert np.unique(np.array(ImageChops.difference(lab_img, expected_value)))[0] == 0
+
+
+@pytest.mark.parametrize(
+    "pil_image", (RGBA.DIAGNOSTIC_SLIDE_THUMB, GS.DIAGNOSTIC_SLIDE_THUMB_GS),
+)
+def test_rgb_to_lab_raises_exception_on_gs_and_rgba_image(pil_image):
+    with pytest.raises(Exception) as err:
+        imf.rgb_to_lab(pil_image)
+
+    assert isinstance(err.value, Exception)
+    assert str(err.value) == "Input image must be RGB"
